/**
 * Copyright 2010-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.protocol.api;

import java.io.Closeable;

/**
 *
 * @author Loris Bouzonnet
 */
public interface IShell extends Closeable {

    /**
     * Executes a command.
     *
     * @param command the command to execute.
     * @throws ProtocolException
     */
    void execute (String command) throws ProtocolException;

    /**
     * Sets a variable.
     *
     * @param name the name of the variable.
     * @param value the value of the variable.
     */
    void setVariable (String name, String value) throws ProtocolException;

    /**
     * Unsets a variable.
     *
     * @param name the name of the variable.
     */
    void unsetVariable (String name) throws ProtocolException;

}
