/**
 * Copyright 2010-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.protocol.api;

/**
 *
 * @author Loris Bouzonnet
 */
public interface ITransferProvider {

    /**
     * Downloads a source file to a destination file via the transfer protocol.
     *
     * @param source
     *            the source file path to download.
     * @param destination
     *            the destination file path.
     * @param recursive
     *            true if directories are recursively copied
     */
    void download(String source, String destination, boolean recursive) throws ProtocolException;

    /**
     * Uploads a source file to a destination file via the transfer protocol.
     *
     * @param source
     *            the source file path to upload.
     * @param destination
     *            the destination file path.
     * @param recursive
     *            true if directories are recursively copied
     */
    void upload(String source, String destination, boolean recursive) throws ProtocolException;

}
