/**
 * Copyright 2010-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.protocol.impl;

import java.util.concurrent.ConcurrentHashMap;

import org.ow2.util.protocol.api.IProtocolConfigRegistry;
import org.ow2.util.protocol.api.ProtocolConfig;

/**
 * Defines an implementation of the registry, supporting some concurrent accesses.
 *
 * @author Loris Bouzonnet
 */
public class ProtocolConfigRegistryImpl implements IProtocolConfigRegistry {

    private final ConcurrentHashMap<String, ProtocolConfig> configs =
        new ConcurrentHashMap<String, ProtocolConfig>();

    public ProtocolConfig getProtocolConfig(final String id) {
        return configs.get(id);
    }

    public void addProtocolConfig(final String id, final ProtocolConfig config) {
        configs.put(id, config);
    }

    public void removeProtocolConfig(final String id) {
        configs.remove(id);
    }

}
